# Document Diff API Reference

## BoQDiff

::: pygaeb.diff.boq_diff.BoQDiff

## DiffResult

::: pygaeb.diff.models.DiffResult

## DiffSummary

::: pygaeb.diff.models.DiffSummary

## DiffDocInfo

::: pygaeb.diff.models.DiffDocInfo

## Significance

::: pygaeb.diff.models.Significance

## DiffMode

::: pygaeb.diff.models.DiffMode

## ItemDiffSummary

::: pygaeb.diff.models.ItemDiffSummary

## ItemAdded

::: pygaeb.diff.models.ItemAdded

## ItemRemoved

::: pygaeb.diff.models.ItemRemoved

## ItemModified

::: pygaeb.diff.models.ItemModified

## ItemMoved

::: pygaeb.diff.models.ItemMoved

## FieldChange

::: pygaeb.diff.models.FieldChange

## StructureDiffSummary

::: pygaeb.diff.models.StructureDiffSummary

## SectionChange

::: pygaeb.diff.models.SectionChange

## SectionRenamed

::: pygaeb.diff.models.SectionRenamed

## MetadataChange

::: pygaeb.diff.models.MetadataChange
